import { Http } from '@zeedhi/core';
import { Formatting } from '@/util/Utilities';
import { GenericValueController } from '@/controllers/GenericValueController';
import ChangeLabel from '@/helper/Labels';

export class GraphicsController {
  public fillGraphicPie({ component }) {
    const props = component.options.props;
    const routeName = props.routeName;
    const seriesNameColumn = props.seriesNameColumn;
    const labelsNameColumn = props.labelsNameColumn;
    const formatting = new Formatting();
    const newLabels = [];
    const newSeries = [];
    const sendObject = {
      filter: [],
    };
    const genericTest = localStorage.getItem('GENERIC_VALUE');
    
    if (props.idOrigem) {
      sendObject.filter.push(
        {
          name: 'IDORIGEM',
          operator: '=',
          value: props.idOrigem,
        },
      );
    }
    
    if (genericTest === 'false' || genericTest === null) {
      Http.post(`/${routeName}`, sendObject).then((response) => {
        /* eslint no-console: ["error", { allow: ["warn", "error", "info", "log"] }] */
        const data = response.data.dataset[routeName];
        data.forEach((row) => {
          newLabels.push(ChangeLabel.getLabel(row[labelsNameColumn]));
          newSeries.push(row[seriesNameColumn]);
        });
        component.series = newSeries;
        const options = {
          labels: newLabels,
          yaxis: {
            labels: {
              formatter: (value) => (
                formatting.formatValue('float', value)
              ),
            },
          },
        };
        component.updateChart(options);
      });
    } else {
      const genericValues = new GenericValueController();
      const data = genericValues.valueGraphicPie[component.name].slice(0, 10);
      
      data.forEach((row) => {
        newLabels.push(ChangeLabel.getLabel(row[labelsNameColumn]));
        newSeries.push(row[seriesNameColumn]);
      });
      component.series = newSeries;
      const options = {
        labels: newLabels,
        yaxis: {
          labels: {
            formatter: (value) => (
              formatting.formatValue('float', value)
            ),
          },
        },
      };
      component.updateChart(options);
    }
  }
  
  public async fillGraphicBar({ component }) {
    const props = component.options.props;
    const routeName = props.routeName;
    const xaxisNameColumn = props.xaxisNameColumn;
    const seriesProps = props.series;
    const formatting = new Formatting();
    const limit = props.limit ? props.limit : 10;
    const sendObject = {
      filter: [],
    };
    const genericValues = new GenericValueController();
    const genericTest = localStorage.getItem('GENERIC_VALUE');
    // let data;
    
    if (genericTest === 'false' || genericTest === null) {
      if (props.idOrigem) {
        sendObject.filter.push(
          {
            name: 'IDORIGEM',
            operator: '=',
            value: props.idOrigem,
          },
        );
      } else if (props.complete) {
        sendObject.filter.push(
          {
            name: 'COMPLETE',
            operator: '=',
            value: props.complete,
          },
        );
      }
      
      Http.post(`/${routeName}`, sendObject).then((response) => {
        /* eslint no-console: ["error", { allow: ["warn", "error", "info", "log"] }] */
        const data = response.data.dataset[routeName].slice(0, limit);
        const xaxis = [];
        const newSeries = [];
        Object.keys(seriesProps).forEach((prop) => {
          newSeries.push({
            name: seriesProps[prop].label,
            data: data.map((item) => item[prop]),
          });
        });
        
        data.forEach((row) => { xaxis.push(row[xaxisNameColumn].substring(0, 15)); });
        component.series = newSeries;
        const options = {
          yaxis: {
            labels: {
              formatter: (value) => (
                formatting.formatValue('float', value)
              ),
            },
          },
          xaxis: {
            categories: xaxis,
          },
        };
        component.updateChart(options);
      });
    } else {
      const data = genericValues.valueGraphicBar[component.name].slice(0, limit);
      const xaxis = [];
      const newSeries = [];
      Object.keys(seriesProps).forEach((prop) => {
        newSeries.push({
          name: seriesProps[prop].label,
          data: data.map((item) => item[prop]),
        });
      });

      data.forEach((row) => { xaxis.push(row[xaxisNameColumn].substring(0, 15)); });
      component.series = newSeries;
      const options = {
        yaxis: {
          labels: {
            formatter: (value) => (
              formatting.formatValue('float', value)
            ),
          },
        },
        xaxis: {
          categories: xaxis,
        },
      };
      component.updateChart(options);
    }
  }
  
  public fillGraphicGauge({ component }) {
    const props = component.options.props;
    const routeName = props.routeName;
    const sendObject = {
      filter: [],
    };
    
    Http.post(`/${routeName}`, sendObject).then((response) => {
      const data = response.data.dataset[routeName][0];
      const options = {
        title: {
          text: `${data.DSINDICADOR} - ${data.DATAAPURADO}`,
          subtext: `(Meta: ${data.VRLIMMETA}%)`,
        },
        series: [
          {
            axisLine: {
              lineStyle: {
                color: [
                  [data.VRLIMMINIMO / 100, 'red'],
                  [data.VRLIMMETA / 100, 'yellow'],
                  [1, 'green'],
                ],
              },
            },
            data: [
              {
                value: data.ENTREGA_TOTAL,
              },
            ],
          },
        ],
      };
      component.updateChart(options);
    });
  }
  
  public tableData({ component }) {
    const formatting = new Formatting();
    const routeName = component.name;
    const sendObject = {
      filter: [],
    };
    let data;
    
    const genericValues = new GenericValueController();
    const genericTest = localStorage.getItem('GENERIC_VALUE');
    
    if (genericTest === 'false' || genericTest === null) {
      Http.post(`/${routeName}`, sendObject).then((response) => {
        data = response.data.dataset[routeName].map((obj) => {
          Object.keys(obj).forEach((key) => {
            if (typeof obj[key] === 'number') {
              obj[key] = formatting.formatValue('float', obj[key]);
            }
          });
        
          return obj;
        });
        component.datasource.updateData(data);
      });
    } else {
      data = genericValues.valueGraphicBar[routeName].map((obj) => {
        Object.keys(obj).forEach((key) => {
          if (typeof obj[key] === 'number') {
            obj[key] = formatting.formatValue('float', obj[key]);
          }
        });
      
        return obj;
      });
      
      component.datasource.updateData(data);
    }
  }
  
  public tableForSelectedData({ component }) {
    const formatting = new Formatting();
    const routeName = component.name;
    const selectedData = component.datasource.filter.SELECTED;
    const sendObject = {
      filter: [
        {
          name: 'SELECTED',
          operator: '=',
          value: selectedData,
        },
      ],
    };
    let data;
    const genericTest = localStorage.getItem('GENERIC_VALUE');
    
    if (genericTest === 'false' || genericTest === null) {
      Http.post(`/${routeName}`, sendObject).then((response) => {
        data = response.data.dataset[routeName].map((obj) => {
          Object.keys(obj).forEach((key) => {
            if (typeof obj[key] === 'number') {
              obj[key] = formatting.formatValue('float', obj[key]);
            }
          });
        
          return obj;
        });
        component.datasource.setFilter([]);
        component.datasource.updateData(data);
      });
    } else {
      const genericValues = new GenericValueController();
      data = genericValues.valueGrid[component.name].map((obj) => {
        Object.keys(obj).forEach((key) => {
          if (typeof obj[key] === 'number') {
            obj[key] = formatting.formatValue('float', obj[key]);
          }
        });
      
        return obj;
      });
      
      component.datasource.updateData(data);
    }
  }
}
