interface InfoIndic {
  id: number;
  limMeta: number;
  limMinimo: number;
}

interface InitialPanelSetup {
  loaded: string;
  orderIndicDashGU: string;
  orderIndicDashGO: string;
  orderIndicDashAC: string;
  orderIndicDashTA: string;
}

class SharedInfo {
  private loadingPromise: Promise<void> | null = null;
  
  public loadingSolve: (() => void) | null = null;
  
  private infoIndic: InfoIndic[] = [
    { id: 1, limMeta: 10, limMinimo: 2 },
    { id: 19, limMeta: 10000, limMinimo: 2200 },
    { id: 3, limMeta: 7, limMinimo: 2 },
    { id: 4, limMeta: 5000, limMinimo: 1000 },
    { id: 5, limMeta: 1500, limMinimo: 500 },
    { id: 21, limMeta: 10, limMinimo: 3 },
  ];
  
  private initialPanelSetup: InitialPanelSetup = {
    loaded: 'N',
    orderIndicDashGU: '',
    orderIndicDashGO: '',
    orderIndicDashAC: '',
    orderIndicDashTA: '',
  };

  getInfoIndic(): InfoIndic[] {
    return this.infoIndic;
  }
  
  setLimit(id: number, newMeta: number, newMinimum: number): void {
    const indic = this.infoIndic.find((obj) => obj.id === id);
    if (indic) {
      indic.limMeta = newMeta;
      indic.limMinimo = newMinimum;
    }
  }

  getSingleRun(): boolean {
    return this.initialPanelSetup.loaded === 'Y';
  }

  getOrderPanel(panel: string): string {
    let orderPanel;
    switch (panel) {
      case 'dashGU': orderPanel = this.initialPanelSetup.orderIndicDashGU;
        break;
      case 'dashGO': orderPanel = this.initialPanelSetup.orderIndicDashGO;
        break;
      case 'dashAC': orderPanel = this.initialPanelSetup.orderIndicDashAC;
        break;
      case 'dashTA': orderPanel = this.initialPanelSetup.orderIndicDashTA;
        break;
      default: orderPanel = '';
    }
    return orderPanel;
  }
  
  setOrderPanel(loaded: string, dashGU: string, dashGO: string, dashAC: string, dashTA: string): void {
    this.initialPanelSetup.loaded = loaded;
    this.initialPanelSetup.orderIndicDashGU = dashGU;
    this.initialPanelSetup.orderIndicDashGO = dashGO;
    this.initialPanelSetup.orderIndicDashAC = dashAC;
    this.initialPanelSetup.orderIndicDashTA = dashTA;
  }
  
  async waitMyBrother(): Promise<void> {
    if (this.getSingleRun) {
      if (!this.loadingPromise) {
        this.loadingPromise = new Promise<void>((solve) => {
          this.loadingSolve = solve;
        });
      }
      
      await this.loadingPromise;
    }
  }
}

export default new SharedInfo();
